@@ -25,10 +25,12 @@
 # established at this point, and setup.py will use a version of next-$(revno).
 # If the releaselevel is 'final', then the tarball will be major.minor.micro.
 # Otherwise it is major.minor.micro~$(revno).
-__version__ = (0, 0, 8, 'beta', 0)
+__version__ = (0, 0, 9, 'beta', 0)
 
 __all__ = [
-    'Config'
+    'Config',
+    'publish_new_only',
     ]
 
 from oops.config import Config
+from oops.publishers import publish_new_only
